#!/bin/bash
#
#SBATCH --job-name=test_all       # job name
#SBATCH --partition=alsacc    # partition
#SBATCH --account=alsacc      # account
#SBATCH --time=40:00:00       # wall clock limit
#SBATCH --nodes=1             # nodes
#SBATCH --ntasks-per-node=24
#SBATCH --constraint=alsacc_c24
#SBATCH --mem=62G
#  --mem command really only needed for alsacc_c16;
#     for alsacc_c12, must leave out or replace --mem=62G with --mem=23G
# nodes:
#    00-27, 28 total, 12 cores each; alsacc_c12
#    28-43, 16 total, 16 cores each; alsacc_c16
#    44-55, 12 total, 20 cores each; alsacc_c20
#    56-63,  8 total, 24 cores each; alsacc_c24
# can check status using sinfo -p alsacc, or scontrol show node n0000.alsacc0
echo "starting run"
date
pwd

cd $SLURM_SUBMIT_DIR
echo 'Working directory is: ' $SLURM_SUBMIT_DIR

echo 'Nodes used: '
echo $SLURM_JOB_NODELIST
echo 'alt: '
echo $SLURM_NODELIST
echo 'slurm_jobid: ' $SLURM_JOBID
echo 'slurm_nprocs: ' $SLURM_NPROCS
echo 'slurm_ntasks: ' $SLURM_NTASKS
echo 'slurm_nnodes: ' $SLURM_NNODES
echo 'slurm_job_nnodes: ' $SLURM_JOB_NNODES
echo 'slurm_job_num_nodes: ' $SLURM_JOB_NUM_NODES
echo 'slurm_cpus_on_node:  ' $SLURM_CPUS_ON_NODE
echo 'slurm_cpus_per_task:  ' $SLURM_CPUS_PER_TASK
echo 'slurm_ntasks_per_node:' $SLURM_NTASKS_PER_NODE
echo 'slurm_ntasks_per_socket: ' $SLURM_NTASKS_PER_SOCKET
echo 'slurm_job_cpus_per_node: ' $SLURM_JOB_CPUS_PER_NODE

NCPUS=$SLURM_NPROCS

echo " "
echo "Number of CPUS:  " $NCPUS
echo " -----------------------------------------------"
module unload intel
module load gcc
module load mkl
module load gsl
module load openmpi
module load python/2.7

module list
echo ""
echo "prepare"
date

root='test'

fname=$root'_DA'
elegant $fname'.ele' > $fname'.txt'
sddsconvert -ascii $fname'.aper' $fname'.aper.txt'
sddsconvert -ascii $fname'.clo' $fname'.clo.txt'

#
fname=$root'_MA'
echo "mpirun -n $NCPUS Pelegant $root$label'.ele' > $root$label'.txt'"
mpirun -n $NCPUS Pelegant $fname'.ele' > $fname'.txt'
sddssort -column=s $fname'.mmap' $fname'.mmapS'
sddsprintout $fname'.mmapS' $fname'_el.txt' -columns='(ElementOccurence,s,deltaPositive,deltaNegative)' -noLabels -formatDefaults=double='%20.15g'
circ=`sddsprocess $fname'.twi' -pipe=out -process=s,max,sMax | sdds2stream -pipe -parameter=sMax`
sddsprocess $fname'.mmapS' $fname'.mmap0' -clip=1,0,invert -redefine=col,s,"s $circ +",units=m
sddscombine $fname'.mmapS' $fname'.mmap0' -merge $fname'.mmap1' -overwrite

echo 'done MA'
date

fname=$root'_MC'
echo "mpirun -n $NCPUS Pelegant $fname'.ele' > $fname'.txt'"
mpirun -n $NCPUS Pelegant $fname'.ele' > $fname'.txt'
#
bash ./processMC.sh

echo 'done'
date

