import numpy as np
from matplotlib import use
use('Agg') # Must be before importing matplotlib.pyplot or pylab
import matplotlib.pyplot as plt
from matplotlib import rcParams
c=np.loadtxt('finalresult.txt',delimiter=' ')
ndiv=c.shape[0] # ring is subdivided into this many elements
ndivlowres=192
ngroup=ndiv/ndivlowres
if (ngroup<1):
    ngroup=1
slen=16.37579629607355
totalloss=c.sum(axis=0)[1]
shift=0
#nshift=0
#cshift=np.roll(c,nshift,axis=0)
cshift=np.zeros(c.shape)
cshift[:,0]=c[:,0]-shift
cshift[:,1]=c[:,1]

# other scalings for plotting
nsec=1 # number sections simulated (out of 12)
allsector=12
charge=1.15e-9
harm=328
nbunch=284
energy=2e9
ee=1.602177e-19
reftime=3600 # nominal lifetime (1 hr)
scale=1.e6*nsec/allsector*harm/nbunch

# divide circumference into sections
#pp=range(0,nsbin*allsector+1,nsbin)
pp=np.linspace(0,ndiv,allsector+1,dtype=np.int16)
# gather data
sectordata=np.zeros((ndiv/allsector,2))
shiftdata=np.zeros((ndiv/allsector,2,allsector))
sectorlow=np.zeros((ndivlowres/allsector,2))
lowresdata=np.zeros((ndivlowres/allsector,2,allsector))
lowresloss=np.zeros((ndivlowres,2))
for isector in range(allsector):
    sectordata[:,:]=cshift[pp[isector]:pp[isector+1],:]
    shiftdata[:,0,isector]=sectordata[:,0]%slen
    shiftdata[:,1,isector]=sectordata[:,1]
    for ig in range(ndivlowres/allsector):
        sectorlow[ig,0]= sectordata[(ig*ngroup):((ig+1)*ngroup),0].mean()
        sectorlow[ig,1]= sectordata[(ig*ngroup):((ig+1)*ngroup),1].sum()
    lowresdata[:,0,isector]=sectorlow[:,0]%slen
    lowresdata[:,1,isector]=sectorlow[:,1]
    lowresloss[(isector*ndivlowres/allsector):((isector+1)*ndivlowres/allsector),0]=((lowresdata[:,0,isector]+shift)%slen-shift+slen*isector)%(slen*allsector)
    lowresloss[(isector*ndivlowres/allsector):((isector+1)*ndivlowres/allsector),1]=lowresdata[:,1,isector]
np.savetxt('finalresult_lowres.txt',lowresloss,newline='\n')

line1,=plt.plot(shiftdata[:,0,0],shiftdata[:,1,0]/scale,'ro')
line2,=plt.plot(shiftdata[:,0,1],shiftdata[:,1,1]/scale,'rs')
line3,=plt.plot(shiftdata[:,0,2],shiftdata[:,1,2]/scale,'r^')
line4,=plt.plot(shiftdata[:,0,3],shiftdata[:,1,3]/scale,'go')
line5,=plt.plot(shiftdata[:,0,4],shiftdata[:,1,4]/scale,'gs')
line6,=plt.plot(shiftdata[:,0,5],shiftdata[:,1,5]/scale,'g^')
line7,=plt.plot(shiftdata[:,0,6],shiftdata[:,1,6]/scale,'bo')
line8,=plt.plot(shiftdata[:,0,7],shiftdata[:,1,7]/scale,'bs')
line9,=plt.plot(shiftdata[:,0,8],shiftdata[:,1,8]/scale,'b^')
line10,=plt.plot(shiftdata[:,0,9],shiftdata[:,1,9]/scale,'ko')
line11,=plt.plot(shiftdata[:,0,10],shiftdata[:,1,10]/scale,'ks')
line12,=plt.plot(shiftdata[:,0,11],shiftdata[:,1,11]/scale,'k^')

plt.legend([line1,line2,line3,line4,line5,line6,line7,line8,line9,line10,line11,line12],['sec1','sec2','sec3','sec4','sec5','sec6','sec7','sec8','sec9','sec10','sec11','sec12'],loc='upper center',bbox_to_anchor=(1.025,1.0),fontsize=10)

plt.xlabel('s/m',fontsize=18)
plt.ylabel("loss rate ($10^6$ $s^{-1}$)",fontsize=18)
plt.title('loss rate for each sector of alsu',fontsize=18)
#plt.axis([0, 17.8, 0, 10.])
plt.xlim(-0.2, 17.9)
plt.xticks(np.arange(0,17.8,2))
plt.ylim(bottom=0)
#plt.title('lifetime evolution with cavity voltage',fontsize=18)
rcParams.update({'font.size': 18, 'font.family': 'serif'})
print(c.sum(axis=0)[1])
#rcParams['xtick.minor.size'] =18
#rcParams['ytick.minor.size'] =18
plt.savefig("loss_sections.pdf")
plt.clf()

# replot:  log plot, and scaled to actual lifetime
aa=np.genfromtxt('summaryT.txt', delimiter=None, dtype=float)
totscat=aa[0]
totloss=aa[1]
maxloss=aa[2]
ignored=aa[3]
ndiv2=int(aa[4])
refloss=harm*charge/ee*nsec/allsector/reftime
lifetime=refloss/totalloss
rescale=totalloss
losses=np.array([totloss,totloss+0.5*ignored*totscat,maxloss])
maxloss2=totloss+ignored*totscat
lifetimes=refloss/losses
print 'loss summary: ',totalloss,totloss,totloss+0.5*ignored*totscat,maxloss,maxloss2
print 'lifetime summary: ',refloss/losses
outdata=open('calculations.txt','w')
print >> outdata, 'loss summary: ',totalloss,totloss,totloss+0.5*ignored*totscat,maxloss,maxloss2
print >> outdata, 'lifetime summary: ',refloss/losses
outdata.close()

rcParams.update({'font.size': 12, 'font.family': 'serif'})
line1,=plt.semilogy(shiftdata[:,0,0],shiftdata[:,1,0]/rescale,'ro')
line2,=plt.semilogy(shiftdata[:,0,1],shiftdata[:,1,1]/rescale,'rs')
line3,=plt.semilogy(shiftdata[:,0,2],shiftdata[:,1,2]/rescale,'r^')
line4,=plt.semilogy(shiftdata[:,0,3],shiftdata[:,1,3]/rescale,'go')
line5,=plt.semilogy(shiftdata[:,0,4],shiftdata[:,1,4]/rescale,'gs')
line6,=plt.semilogy(shiftdata[:,0,5],shiftdata[:,1,5]/rescale,'g^')
line7,=plt.semilogy(shiftdata[:,0,6],shiftdata[:,1,6]/rescale,'bo')
line8,=plt.semilogy(shiftdata[:,0,7],shiftdata[:,1,7]/rescale,'bs')
line9,=plt.semilogy(shiftdata[:,0,8],shiftdata[:,1,8]/rescale,'b^')
line10,=plt.semilogy(shiftdata[:,0,9],shiftdata[:,1,9]/rescale,'ko')
line11,=plt.semilogy(shiftdata[:,0,10],shiftdata[:,1,10]/rescale,'ks')
line12,=plt.semilogy(shiftdata[:,0,11],shiftdata[:,1,11]/rescale,'k^')

plt.legend([line1,line2,line3,line4,line5,line6,line7,line8,line9,line10,line11,line12],['sec1','sec2','sec3','sec4','sec5','sec6','sec7','sec8','sec9','sec10','sec11','sec12'],loc='upper center',bbox_to_anchor=(1.025,1.0),fontsize=10)

plt.xlabel('s (m)',fontsize=18)
plt.ylabel('fraction of losses each interval',fontsize=18)
plt.title('Distribution of losses: nominal apertures',fontsize=18)
plt.xlim(-0.2, 17.9)
plt.xticks(np.arange(0,17.8,2))
plt.ylim(bottom=1e-4,top=1)
plt.tight_layout()
plt.subplots_adjust(right=0.9,left=0.14)
plt.savefig("loss_log.pdf")
plt.clf()

line1,=plt.semilogy(lowresdata[:,0,0],lowresdata[:,1,0]/rescale,'ro')
line2,=plt.semilogy(lowresdata[:,0,1],lowresdata[:,1,1]/rescale,'rs')
line3,=plt.semilogy(lowresdata[:,0,2],lowresdata[:,1,2]/rescale,'r^')
line4,=plt.semilogy(lowresdata[:,0,3],lowresdata[:,1,3]/rescale,'go')
line5,=plt.semilogy(lowresdata[:,0,4],lowresdata[:,1,4]/rescale,'gs')
line6,=plt.semilogy(lowresdata[:,0,5],lowresdata[:,1,5]/rescale,'g^')
line7,=plt.semilogy(lowresdata[:,0,6],lowresdata[:,1,6]/rescale,'bo')
line8,=plt.semilogy(lowresdata[:,0,7],lowresdata[:,1,7]/rescale,'bs')
line9,=plt.semilogy(lowresdata[:,0,8],lowresdata[:,1,8]/rescale,'b^')
line10,=plt.semilogy(lowresdata[:,0,9],lowresdata[:,1,9]/rescale,'ko')
line11,=plt.semilogy(lowresdata[:,0,10],lowresdata[:,1,10]/rescale,'ks')
line12,=plt.semilogy(lowresdata[:,0,11],lowresdata[:,1,11]/rescale,'k^')

plt.legend([line1,line2,line3,line4,line5,line6,line7,line8,line9,line10,line11,line12],['sec1','sec2','sec3','sec4','sec5','sec6','sec7','sec8','sec9','sec10','sec11','sec12'],loc='upper center',bbox_to_anchor=(1.025,1.0),fontsize=10)

plt.xlabel('s (m)',fontsize=18)
plt.ylabel('fraction of losses each interval',fontsize=18)
plt.title('Distribution of losses',fontsize=18)
plt.xlim(-0.2, 17.9)
plt.xticks(np.arange(0,17.8,2))
plt.ylim(bottom=1e-4,top=1)
plt.tight_layout()
plt.subplots_adjust(right=0.9,left=0.14)
plt.savefig("loss_log_lowres.pdf")
plt.clf()

